# DesertIslandUtils Markdown Formatter

## markdowner
* cron job
* uppercase all `## \w+`
* equivalent `sed 's:## \(\w+\):\U\1:' file.md`
* write in python

## TEST: file open in vscode, changed by cron job underneath

## RSRC
https://stackoverflow.com/questions/38633787/how-to-edit-lines-of-all-text-files-in-a-directory-with-python
https://stackoverflow.com/questions/12714415/python-equivalent-to-sed
